@@ -41,9 +41,9 @@ struct KBounceVector
 {
     qreal x, y;
 
-    KBounceVector( qreal newx = 0, qreal newy = 0 ) : x( newx ), y( newy ) {};
+    KBounceVector( qreal newx = 0, qreal newy = 0 ) : x( newx ), y( newy ) {}
 
-    KBounceVector& operator+=( const KBounceVector& rv )
+    KBounceVector& operator+=(KBounceVector rv )
     {
         x += rv.x; y += rv.y; 
         return *this;
